summaryrefslogtreecommitdiffstats
path: root/ksquirrel/ksquirrel.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksquirrel/ksquirrel.h')
-rw-r--r--ksquirrel/ksquirrel.h95
1 files changed, 48 insertions, 47 deletions
diff --git a/ksquirrel/ksquirrel.h b/ksquirrel/ksquirrel.h
index 58c542b..9300946 100644
--- a/ksquirrel/ksquirrel.h
+++ b/ksquirrel/ksquirrel.h
@@ -22,8 +22,8 @@
#include <config.h>
#endif
-#include <qstringlist.h>
-#include <qmap.h>
+#include <tqstringlist.h>
+#include <tqmap.h>
#include <kmainwindow.h>
#include <dcopobject.h>
@@ -32,13 +32,13 @@
// forward declarations
-template <class T> class QValueVector;
-class QLabel;
-class QWidgetStack;
-class QHBox;
-class QVBox;
-class QTimer;
-class QSplitter;
+template <class T> class TQValueVector;
+class TQLabel;
+class TQWidgetStack;
+class TQHBox;
+class TQVBox;
+class TQTimer;
+class TQSplitter;
namespace KIO { class Job; }
@@ -78,12 +78,13 @@ class SQ_SlideShowListing;
class KSquirrel : public KMainWindow, public DCOPObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/*
* Constructor & destructor
*/
- KSquirrel(QWidget *parent, const char *name);
+ KSquirrel(TQWidget *tqparent, const char *name);
~KSquirrel();
SQ_Progress* diskProgress();
@@ -126,7 +127,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
* will be set to it, and to KSquirrel's main window
* otherwise. Called from SQ_GLWidget.
*/
- void setCaption(const QString &cap);
+ void setCaption(const TQString &cap);
void saveLayout();
@@ -149,9 +150,9 @@ class KSquirrel : public KMainWindow, public DCOPObject
/*
* Get pointer to a widget, located in status bar.
* All pointers to statusbar widgets are saved in
- * 'sbarwidgets' object (QMap).
+ * 'sbarwidgets' object (TQMap).
*/
- QLabel* sbarWidget(const QString &name);
+ TQLabel* sbarWidget(const TQString &name);
/*
* DCOP methods
@@ -165,7 +166,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
/*
* Process incoming DCOP message
*/
- bool process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData);
+ bool process(const TQCString &fun, const TQByteArray &data, TQCString& replyType, TQByteArray &replyData);
bool separateImageWindow() const;
@@ -173,8 +174,8 @@ class KSquirrel : public KMainWindow, public DCOPObject
* Names and extensions of name filters for
* file manager.
*/
- QStringList* filtersNames() const;
- QStringList* filtersExtensions() const;
+ TQStringList* filtersNames() const;
+ TQStringList* filtersExtensions() const;
static KSquirrel* app() { return m_instance; }
@@ -182,9 +183,9 @@ class KSquirrel : public KMainWindow, public DCOPObject
/*
* Catch some events and do specific actions.
*/
- virtual bool eventFilter(QObject *o, QEvent *e);
- virtual void closeEvent(QCloseEvent *e);
- virtual void resizeEvent(QResizeEvent *e);
+ virtual bool eventFilter(TQObject *o, TQEvent *e);
+ virtual void closeEvent(TQCloseEvent *e);
+ virtual void resizeEvent(TQResizeEvent *e);
/*
* Internal methods
@@ -234,7 +235,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
void preCreate();
/*
- * Create QStrinLists, containing filters and filters' names (if needed)
+ * Create TQStrinLists, containing filters and filters' names (if needed)
* and fill popup menu with new filters.
*/
void initFilterMenu();
@@ -294,7 +295,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
* Set filter for a filemanager to 'f' and check
* appropriate menu item
*/
- void setFilter(const QString &f, const int id);
+ void setFilter(const TQString &f, const int id);
/*
* Fill 'messages' map with values. 'messages' map is used
@@ -312,7 +313,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
* key sequence and send this sequence to SQ_GLWidget.
*
* The main idea is that KSquirrel will find needed key sequence
- * by its name (in 'messages' map), costruct QKeyEvent and send to
+ * by its name (in 'messages' map), costruct TQKeyEvent and send to
* SQ_GLWidget. SQ_GLWidget already has keyEvent() handler, so it will
* do what DCOP client wants.
*
@@ -321,29 +322,29 @@ class KSquirrel : public KMainWindow, public DCOPObject
* $ dcop ksquirrel ksquirrel control image_next
*
* will call KSquirrel::control("image_next"), which will
* construct QKeyEvent(QEvent::KeyPress, Qt::Key_PageDown,
* Qt::Key_PageDown, Qt::NoButton)
* and send it to SQ_GLWidget. SQ_GLWidget will catch keypress event,
* and load next image in the current directory.
*/
- void control(const QString &command);
+ void control(const TQString &command);
/*
* Send a message to navigator from incoming DCOP message
*/
- void navigatorSend(const QString &command);
+ void navigatorSend(const TQString &command);
/*
* Get QString argument from incoming QByteArray.
*/
- QString getArg(const QByteArray &data);
+ TQString getArg(const TQByteArray &data);
signals:
/*
* emitted, when user chages thumbails' size (from menu).
*/
- void thumbSizeChanged(const QString&);
+ void thumbSizeChanged(const TQString&);
void resetToolTip();
@@ -610,39 +611,39 @@ class KSquirrel : public KMainWindow, public DCOPObject
KStatusBar *sbar;
// contains paths of found libraries
- QStringList strlibFound;
+ TQStringList strlibFound;
// sizes for mainSplitter
- QValueList<int> mainSizes;
+ TQValueList<int> mainSizes;
// libraries' filters
- QStringList libFilters;
+ TQStringList libFilters;
- // QMap, which contains pointers to statusbar widgets.
+ // TQMap, which contains pointers to statusbar widgets.
// I can get a pointer by widget's name.
//
// For example:
//
// KSquirrel::app()->sbarWidget("fileName")->setText("Filename.txt");
//
- QMap<QString, QLabel*> sbarwidgets;
+ TQMap<TQString, TQLabel*> sbarwidgets;
- // QLabels for statusbar
- QLabel *dirInfo, *fileIcon, *fileName, *diskSpace;
+ // TQLabels for statusbar
+ TQLabel *dirInfo, *fileIcon, *fileName, *diskSpace;
- // QMap, which contains available DCOP
+ // TQMap, which contains available DCOP
// parameters (such as "image_next", "image_prev")
// and its appropriate key sequences.
//
- // For example, "image_next" is mapped to Qt::Key_PageDown
- // "image_prev" - to "Qt::Key_PageUp"
- QMap<QString, int> messages;
+ // For example, "image_next" is mapped to TQt::Key_PageDown
+ // "image_prev" - to "TQt::Key_PageUp"
+ TQMap<TQString, int> messages;
// combobox with history urls
KHistoryCombo *pCurrentURL;
// filters' names and extensions
- QStringList *sqFiltersName, *sqFiltersExt;
+ TQStringList *sqFiltersName, *sqFiltersExt;
// "Configure KSquirrel"
KAction *pAConfigure,
@@ -667,7 +668,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
// Directory for slideshow.
// KSquirrel will use it to load file names.
- QString slideShowDir;
+ TQString slideShowDir;
bool slideShowInit;
@@ -684,7 +685,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
KURL slideShowName;
// timers for slideshow
- QTimer *slideShowTimer, *timerShowListing;
+ TQTimer *slideShowTimer, *timerShowListing;
// is slideshow stopped ?
bool slideShowStop;
@@ -707,7 +708,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
// external tools
SQ_ExternalTool *extool;
- QSplitter *mainView;
+ TQSplitter *mainView;
// file tree
SQ_TreeView *ptree;
@@ -744,7 +745,7 @@ class KSquirrel : public KMainWindow, public DCOPObject
int old_id;
bool old_disable, m_urlbox, old_marks, old_calc, m_intray, waitForShow;
SQ_Downloader *down;
- QVBox *mainPage;
+ TQVBox *mainPage;
bool statStage;
};
@@ -762,13 +763,13 @@ KHistoryCombo* KSquirrel::historyCombo()
}
inline
-QStringList* KSquirrel::filtersNames() const
+TQStringList* KSquirrel::filtersNames() const
{
return sqFiltersName;
}
inline
-QStringList* KSquirrel::filtersExtensions() const
+TQStringList* KSquirrel::filtersExtensions() const
{
return sqFiltersExt;
}
@@ -321,29 +322,29 @@ class KSquirrel : public KMainWindow, public DCOPObject
*
* will call KSquirrel::control("image_next"), which will
- * construct QKeyEvent(QEvent::KeyPress, Qt::Key_PageDown,
- * Qt::Key_PageDown, Qt::NoButton)
+ * construct TQKeyEvent(TQEvent::KeyPress, TQt::Key_PageDown,
+ * TQt::Key_PageDown, Qt::NoButton)
* and send it to SQ_GLWidget. SQ_GLWidget will catch keypress event,
* and load next image in the current directory.
@@ -321,29 +322,29 @@ class KSquirrel : public KMainWindow, public DCOPObject
/*
- * Get QString argument from incoming QByteArray.
+ * Get TQString argument from incoming TQByteArray.
*/